function [alpha,valfder]=val_derivee_multiple(i,X,Y)


%	val_derivee_multiple : sortie des valeurs des drives successives pour un support quelconque
%
% *********************************************************
%
%	[alpha,valfder]=val_derivee_multiple(i,X,Y)
%     sorties des valeurs des drives successives (dfinies dans Y)      
%     pour un support  n+1 points quelconque (ordonne) stock dans X,
%     pour un lment x_i de ce support.
%
%
%	variables d'entres : 
%     * i : entier compris entre 0 et n
%     * X : contient les valeurs x_j, pour 0 <=j<=n (dans l'ordre croissant)
%     * Y : contient les valeurs f^(r)(x_j), pour 0 <=j<=n, de telle sorte que :
%             si x_k est multiple avec x_{k-1}~=x_k=x_{k+1}=...=x_{k+r}~=x_{k+r+1} alors
%                y_k=f(x_k), y_{k+1}=f'(x_k), ..., y_{k+r}=f^(r)(x_k).
%
%	variables de sortie
%     *  alpha : nombre d'lments du n+1 uplet (x_0,x_1,...,x_n) gaux  x_i.     
%     *  valfder : vecteur ligne de longueur alpha tel que :
%                 pour tout l dans {0,...,alpha-1}; valfder(l+1)=f^{l}(x_i).
% 
% 
% ************ Fonctions auxiliaires utilises ************
%
%       aucune
%
% *********************************************************
%


% Contrles d'entre
%
% nombre d'arguments
if nargin~=3
   error('nombre d''arguments de la fonction incorrect');
end
% taille des deux variables 
n=length(X)-1;
np=length(Y)-1;
if n~=np
   error('les deux tableaux n''ont pas la mme taille');
end
% vrification de l'ordre croissant des x_i 
% (si X non formel)
if isnumeric(X)
   if max(abs(sort(X)-X))~=0
      error('support non ordonn');
   end
end
% vrification de l'appartenance de i  {0,...,n}
% vrification de l'ordre croissant des x_i 
if ~((0<=i) & (i<=n)) 
   error('le premier argument n''appartient pas  {0,...,n}');
end


% Corps d'algorithme
k=find(X==X(i+1));
alpha=length(k);
valfder=Y(k);